<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>QBluetoothDeviceDiscoveryAgent</name>
    <message>
        <source>Device is powered off</source>
        <translation>设备已关闭</translation>
    </message>
    <message>
        <source>Cannot find valid Bluetooth adapter.</source>
        <translation>找不到有效的蓝牙适配器。</translation>
    </message>
    <message>
        <source>Input Output Error</source>
        <translation>输入输出错误</translation>
    </message>
    <message>
        <source>Bluetooth LE is not supported</source>
        <translation>不支持低功耗蓝牙</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>未知错误</translation>
    </message>
    <message>
        <source>Cannot start device inquiry</source>
        <translation>无法启动设备查询</translation>
    </message>
    <message>
        <source>Cannot start low energy device inquiry</source>
        <translation>无法启动低能耗设备查询</translation>
    </message>
    <message>
        <source>Discovery cannot be stopped</source>
        <translation>无法停止发现</translation>
    </message>
    <message>
        <source>Invalid Bluetooth adapter address</source>
        <translation>蓝牙适配器地址无效</translation>
    </message>
    <message>
        <source>One or more device discovery methods are not supported on this platform</source>
        <translation>此平台不支持一种或多种设备发现方法</translation>
    </message>
    <message>
        <source>Device does not support Bluetooth</source>
        <translation>设备不支持蓝牙</translation>
    </message>
    <message>
        <source>Passed address is not a local device.</source>
        <translation>传递的地址不是本地设备。</translation>
    </message>
    <message>
        <source>Missing Location permission. Search is not possible.</source>
        <translation>缺少位置权限。无法搜索。</translation>
    </message>
    <message>
        <source>Location service turned off. Search is not possible.</source>
        <translation>位置服务已关闭，无法进行搜索。</translation>
    </message>
    <message>
        <source>Classic Discovery cannot be started</source>
        <translation>无法启动经典发现</translation>
    </message>
    <message>
        <source>Low Energy Discovery not supported</source>
        <translation>不支持低能耗发现</translation>
    </message>
    <message>
        <source>Bluetooth adapter error</source>
        <translation>蓝牙适配器错误</translation>
    </message>
    <message>
        <source>Device discovery not supported on this platform</source>
        <translation>此平台不支持设备发现</translation>
    </message>
    <message>
        <source>Cannot access adapter during service discovery</source>
        <translation>在服务发现期间无法访问适配器</translation>
    </message>
</context>
<context>
    <name>QBluetoothServiceDiscoveryAgent</name>
    <message>
        <source>Local device is powered off</source>
        <translation>本地设备已关闭</translation>
    </message>
    <message>
        <source>Minimal service discovery failed</source>
        <translation>最小服务发现失败</translation>
    </message>
    <message>
        <source>Invalid Bluetooth adapter address</source>
        <translation>蓝牙适配器地址无效</translation>
    </message>
    <message>
        <source>Platform does not support Bluetooth</source>
        <translation>平台不支持蓝牙</translation>
    </message>
    <message>
        <source>Android API below v15 does not support SDP discovery</source>
        <translation>V15 以下的 Android API 不支持 SDP 发现</translation>
    </message>
    <message>
        <source>Cannot create Android BluetoothDevice</source>
        <translation>无法创建 Android 蓝牙设备</translation>
    </message>
    <message>
        <source>Cannot obtain service uuids</source>
        <translation>无法获得服务 uuids</translation>
    </message>
    <message>
        <source>Serial Port Profile</source>
        <translation>串口配置文件</translation>
    </message>
    <message>
        <source>Device is powered off</source>
        <translation>设备已关闭</translation>
    </message>
    <message>
        <source>Unable to find appointed local adapter</source>
        <translation>找不到指定的本地适配器</translation>
    </message>
    <message>
        <source>Cannot find local Bluetooth adapter</source>
        <translation>找不到本地蓝牙适配器</translation>
    </message>
    <message>
        <source>Unable to find sdpscanner</source>
        <translation>无法找到 sdpscanner</translation>
    </message>
    <message>
        <source>Unable to perform SDP scan</source>
        <translation>无法执行 SDP 扫描</translation>
    </message>
    <message>
        <source>Custom Service</source>
        <translation>自定义服务</translation>
    </message>
    <message>
        <source>Unable to access device</source>
        <translation>无法访问设备</translation>
    </message>
    <message>
        <source>Service Discovery</source>
        <translation>服务发现</translation>
    </message>
    <message>
        <source>Browse Group Descriptor</source>
        <translation>浏览组描述符</translation>
    </message>
    <message>
        <source>Public Browse Group</source>
        <translation>公共浏览组</translation>
    </message>
    <message>
        <source>LAN Access Profile</source>
        <translation>LAN 访问配置文件</translation>
    </message>
    <message>
        <source>Dial-Up Networking</source>
        <translation>拨号网络</translation>
    </message>
    <message>
        <source>Synchronization</source>
        <translation>同步</translation>
    </message>
    <message>
        <source>Object Push</source>
        <translation>对象推送</translation>
    </message>
    <message>
        <source>File Transfer</source>
        <translation>文件传输</translation>
    </message>
    <message>
        <source>Synchronization Command</source>
        <translation>同步命令</translation>
    </message>
    <message>
        <source>Headset</source>
        <translation>耳机</translation>
    </message>
    <message>
        <source>Audio Source</source>
        <translation>音频源</translation>
    </message>
    <message>
        <source>Audio Sink</source>
        <translation>音频接收器</translation>
    </message>
    <message>
        <source>Audio/Video Remote Control Target</source>
        <translation>音频/视频 远程控制目标</translation>
    </message>
    <message>
        <source>Advanced Audio Distribution</source>
        <translation>高级音频分发</translation>
    </message>
    <message>
        <source>Audio/Video Remote Control</source>
        <translation>音频/视频 远程控制</translation>
    </message>
    <message>
        <source>Audio/Video Remote Control Controller</source>
        <translation>音频/视频 远程控制器控制器</translation>
    </message>
    <message>
        <source>Headset AG</source>
        <translation>耳机 AG</translation>
    </message>
    <message>
        <source>Personal Area Networking (PANU)</source>
        <translation>个人区域网络（PANU）</translation>
    </message>
    <message>
        <source>Personal Area Networking (NAP)</source>
        <translation>个人区域网络（NAP）</translation>
    </message>
    <message>
        <source>Personal Area Networking (GN)</source>
        <translation>个人区域网络（GN）</translation>
    </message>
    <message>
        <source>Basic Direct Printing (BPP)</source>
        <translation>基本直接打印（BPP）</translation>
    </message>
    <message>
        <source>Basic Reference Printing (BPP)</source>
        <translation>基本参考打印（BPP）</translation>
    </message>
    <message>
        <source>Basic Imaging Profile</source>
        <translation>基本图像配置文件</translation>
    </message>
    <message>
        <source>Basic Imaging Responder</source>
        <translation>基本图像响应者</translation>
    </message>
    <message>
        <source>Basic Imaging Archive</source>
        <translation>基本图像存档</translation>
    </message>
    <message>
        <source>Basic Imaging Ref Objects</source>
        <translation>基本图像引用对象</translation>
    </message>
    <message>
        <source>Hands-Free</source>
        <translation>免提</translation>
    </message>
    <message>
        <source>Hands-Free AG</source>
        <translation>免提 AG</translation>
    </message>
    <message>
        <source>Basic Printing RefObject Service</source>
        <translation>基本打印引用对象服务</translation>
    </message>
    <message>
        <source>Basic Printing Reflected UI</source>
        <translation>基本打印反映 UI</translation>
    </message>
    <message>
        <source>Basic Printing</source>
        <translation>基本打印</translation>
    </message>
    <message>
        <source>Basic Printing Status</source>
        <translation>基本打印状态</translation>
    </message>
    <message>
        <source>Human Interface Device</source>
        <translation>人机接口设备</translation>
    </message>
    <message>
        <source>Hardcopy Cable Replacement</source>
        <translation>硬拷贝电缆替换</translation>
    </message>
    <message>
        <source>Hardcopy Cable Replacement Print</source>
        <translation>硬拷贝电缆替换打印</translation>
    </message>
    <message>
        <source>Hardcopy Cable Replacement Scan</source>
        <translation>硬拷贝电缆替换扫描</translation>
    </message>
    <message>
        <source>SIM Access Server</source>
        <translation>SIM 卡访问服务器</translation>
    </message>
    <message>
        <source>Phonebook Access PCE</source>
        <translation>电话簿访问 PCE</translation>
    </message>
    <message>
        <source>Phonebook Access PSE</source>
        <translation>电话簿访问 PSE</translation>
    </message>
    <message>
        <source>Phonebook Access</source>
        <translation>电话簿访问</translation>
    </message>
    <message>
        <source>Headset HS</source>
        <translation>耳机 HS</translation>
    </message>
    <message>
        <source>Message Access Server</source>
        <translation>消息访问服务器</translation>
    </message>
    <message>
        <source>Message Notification Server</source>
        <translation>消息通知服务器</translation>
    </message>
    <message>
        <source>Message Access</source>
        <translation>消息访问</translation>
    </message>
    <message>
        <source>Global Navigation Satellite System</source>
        <translation>全球导航卫星系统</translation>
    </message>
    <message>
        <source>Global Navigation Satellite System Server</source>
        <translation>全球导航卫星系统服务器</translation>
    </message>
    <message>
        <source>3D Synchronization Display</source>
        <translation>3D 同步显示</translation>
    </message>
    <message>
        <source>3D Synchronization Glasses</source>
        <translation>3D 同步眼镜</translation>
    </message>
    <message>
        <source>3D Synchronization</source>
        <translation>3D 同步</translation>
    </message>
    <message>
        <source>Multi-Profile Specification (Profile)</source>
        <translation>多配置文件规范（配置文件）</translation>
    </message>
    <message>
        <source>Multi-Profile Specification</source>
        <translation>多配置文件规范</translation>
    </message>
    <message>
        <source>Device Identification</source>
        <translation>设备标识</translation>
    </message>
    <message>
        <source>Generic Networking</source>
        <translation>通用网络</translation>
    </message>
    <message>
        <source>Generic File Transfer</source>
        <translation>通用文件传输</translation>
    </message>
    <message>
        <source>Generic Audio</source>
        <translation>通用音频</translation>
    </message>
    <message>
        <source>Generic Telephony</source>
        <translation>通用电话</translation>
    </message>
    <message>
        <source>Video Source</source>
        <translation>视频源</translation>
    </message>
    <message>
        <source>Video Sink</source>
        <translation>视频接收器</translation>
    </message>
    <message>
        <source>Video Distribution</source>
        <translation>视频分发</translation>
    </message>
    <message>
        <source>Health Device</source>
        <translation>健康设备</translation>
    </message>
    <message>
        <source>Health Device Source</source>
        <translation>健康设备源</translation>
    </message>
    <message>
        <source>Health Device Sink</source>
        <translation>健康设备接收器</translation>
    </message>
    <message>
        <source>Generic Access</source>
        <translation>通用访问</translation>
    </message>
    <message>
        <source>Generic Attribute</source>
        <translation>通用属性</translation>
    </message>
    <message>
        <source>Immediate Alert</source>
        <translation>立即警报</translation>
    </message>
    <message>
        <source>Link Loss</source>
        <translation>链路损耗</translation>
    </message>
    <message>
        <source>Tx Power</source>
        <translation>发射功率</translation>
    </message>
    <message>
        <source>Current Time Service</source>
        <translation>当前时间服务</translation>
    </message>
    <message>
        <source>Reference Time Update Service</source>
        <translation>参考时间更新服务</translation>
    </message>
    <message>
        <source>Next DST Change Service</source>
        <translation>下一个 DST 更改服务</translation>
    </message>
    <message>
        <source>Glucose</source>
        <translation>血糖</translation>
    </message>
    <message>
        <source>Health Thermometer</source>
        <translation>健康温度计</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>设备信息</translation>
    </message>
    <message>
        <source>Heart Rate</source>
        <translation>心率</translation>
    </message>
    <message>
        <source>Phone Alert Status Service</source>
        <translation>电话警报状态服务</translation>
    </message>
    <message>
        <source>Battery Service</source>
        <translation>电池服务</translation>
    </message>
    <message>
        <source>Blood Pressure</source>
        <translation>血压</translation>
    </message>
    <message>
        <source>Alert Notification Service</source>
        <translation>警报通知服务</translation>
    </message>
    <message>
        <source>Scan Parameters</source>
        <translation>扫描参数</translation>
    </message>
    <message>
        <source>Running Speed and Cadence</source>
        <translation>跑步速度和节奏</translation>
    </message>
    <message>
        <source>Cycling Speed and Cadence</source>
        <translation>骑行速度和节奏</translation>
    </message>
    <message>
        <source>Cycling Power</source>
        <translation>骑行动力</translation>
    </message>
    <message>
        <source>Location and Navigation</source>
        <translation>位置和导航</translation>
    </message>
    <message>
        <source>Environmental Sensing</source>
        <translation>环境感应</translation>
    </message>
    <message>
        <source>Body Composition</source>
        <translation>身体构成</translation>
    </message>
    <message>
        <source>User Data</source>
        <translation>用户数据</translation>
    </message>
    <message>
        <source>Weight Scale</source>
        <translation>体重秤</translation>
    </message>
    <message>
        <source>Bond Management</source>
        <extracomment>Connection management (Bluetooth)</extracomment>
        <translation>债券管理</translation>
    </message>
    <message>
        <source>Continuous Glucose Monitoring</source>
        <translation>连续血糖监测</translation>
    </message>
    <message>
        <source>Service Discovery Protocol</source>
        <translation>服务发现协议</translation>
    </message>
    <message>
        <source>User Datagram Protocol</source>
        <translation>用户数据报协议</translation>
    </message>
    <message>
        <source>Radio Frequency Communication</source>
        <translation>无线电频率通信</translation>
    </message>
    <message>
        <source>Transmission Control Protocol</source>
        <translation>传输控制协议</translation>
    </message>
    <message>
        <source>Telephony Control Specification - Binary</source>
        <translation>电话控制规范 - 二进制</translation>
    </message>
    <message>
        <source>Telephony Control Specification - AT</source>
        <translation>电话控制规范 -  AT</translation>
    </message>
    <message>
        <source>Attribute Protocol</source>
        <translation>属性协议</translation>
    </message>
    <message>
        <source>Object Exchange Protocol</source>
        <translation>对象交换协议</translation>
    </message>
    <message>
        <source>Internet Protocol</source>
        <translation>互联网协议</translation>
    </message>
    <message>
        <source>File Transfer Protocol</source>
        <translation>文件传输协议</translation>
    </message>
    <message>
        <source>Hypertext Transfer Protocol</source>
        <translation>超文本传输协议</translation>
    </message>
    <message>
        <source>Wireless Short Packet Protocol</source>
        <translation>无线短分组协议</translation>
    </message>
    <message>
        <source>Bluetooth Network Encapsulation Protocol</source>
        <translation>蓝牙网络封装协议</translation>
    </message>
    <message>
        <source>Extended Service Discovery Protocol</source>
        <translation>扩展服务发现协议</translation>
    </message>
    <message>
        <source>Human Interface Device Protocol</source>
        <translation>人机接口设备协议</translation>
    </message>
    <message>
        <source>Hardcopy Control Channel</source>
        <translation>硬拷贝控制通道</translation>
    </message>
    <message>
        <source>Hardcopy Data Channel</source>
        <translation>硬拷贝数据通道</translation>
    </message>
    <message>
        <source>Hardcopy Notification</source>
        <translation>硬拷贝通知</translation>
    </message>
    <message>
        <source>Audio/Video Control Transport Protocol</source>
        <translation>音频/视频 控制传输协议</translation>
    </message>
    <message>
        <source>Audio/Video Distribution Transport Protocol</source>
        <translation>音频/视频 分发传输协议</translation>
    </message>
    <message>
        <source>Common ISDN Access Protocol</source>
        <translation>通用 ISDN 访问协议</translation>
    </message>
    <message>
        <source>UdiCPlain</source>
        <translation>UdiCPlain</translation>
    </message>
    <message>
        <source>Multi-Channel Adaptation Protocol - Control</source>
        <translation>多信道适配协议 - 控制</translation>
    </message>
    <message>
        <source>Multi-Channel Adaptation Protocol - Data</source>
        <translation>多信道适配协议 - 数据</translation>
    </message>
    <message>
        <source>Layer 2 Control Protocol</source>
        <translation>第 2 层控制协议</translation>
    </message>
    <message>
        <source>GAP Device Name</source>
        <extracomment>GAP: Generic Access Profile (Bluetooth)</extracomment>
        <translation>GAP 设备名称</translation>
    </message>
    <message>
        <source>GAP Appearance</source>
        <extracomment>GAP: Generic Access Profile (Bluetooth)</extracomment>
        <translation>GAP 外观</translation>
    </message>
    <message>
        <source>GAP Peripheral Privacy Flag</source>
        <extracomment>GAP: Generic Access Profile (Bluetooth)</extracomment>
        <translation>GAP 周边隐私标志</translation>
    </message>
    <message>
        <source>GAP Reconnection Address</source>
        <extracomment>GAP: Generic Access Profile (Bluetooth)</extracomment>
        <translation>GAP 重新连接地址</translation>
    </message>
    <message>
        <source>GAP Peripheral Preferred Connection Parameters</source>
        <translation>GAP 外设首选连接参数</translation>
    </message>
    <message>
        <source>GATT Service Changed</source>
        <extracomment>GATT: _G_eneric _Att_ribute Profile (Bluetooth)</extracomment>
        <translation>GATT 服务已更改</translation>
    </message>
    <message>
        <source>Alert Level</source>
        <translation>警报级别</translation>
    </message>
    <message>
        <source>TX Power</source>
        <translation>发射功率</translation>
    </message>
    <message>
        <source>Date Time</source>
        <translation>时间日期</translation>
    </message>
    <message>
        <source>Day Of Week</source>
        <translation>星期</translation>
    </message>
    <message>
        <source>Day Date Time</source>
        <translation>当天的日期时间</translation>
    </message>
    <message>
        <source>Exact Time 256</source>
        <translation>确切的时间 256</translation>
    </message>
    <message>
        <source>DST Offset</source>
        <translation>DST 偏移</translation>
    </message>
    <message>
        <source>Time Zone</source>
        <translation>时区</translation>
    </message>
    <message>
        <source>Local Time Information</source>
        <translation>当地时间信息</translation>
    </message>
    <message>
        <source>Time With DST</source>
        <translation>DST 时间</translation>
    </message>
    <message>
        <source>Time Accuracy</source>
        <translation>时间精度</translation>
    </message>
    <message>
        <source>Time Source</source>
        <translation>时间源</translation>
    </message>
    <message>
        <source>Reference Time Information</source>
        <translation>参考时间信息</translation>
    </message>
    <message>
        <source>Time Update Control Point</source>
        <translation>时间更新控制点</translation>
    </message>
    <message>
        <source>Time Update State</source>
        <translation>时间更新状态</translation>
    </message>
    <message>
        <source>Glucose Measurement</source>
        <translation>葡萄糖测定</translation>
    </message>
    <message>
        <source>Battery Level</source>
        <translation>电池电量</translation>
    </message>
    <message>
        <source>Temperature Measurement</source>
        <translation>温度测量</translation>
    </message>
    <message>
        <source>Temperature Type</source>
        <translation>温度类型</translation>
    </message>
    <message>
        <source>Intermediate Temperature</source>
        <translation>中间温度</translation>
    </message>
    <message>
        <source>Measurement Interval</source>
        <translation>测量间隔</translation>
    </message>
    <message>
        <source>Boot Keyboard Input Report</source>
        <translation>启动键盘输入报告</translation>
    </message>
    <message>
        <source>System ID</source>
        <translation>系统 ID</translation>
    </message>
    <message>
        <source>Model Number String</source>
        <translation>型号字符串</translation>
    </message>
    <message>
        <source>Serial Number String</source>
        <translation>序列号字符串</translation>
    </message>
    <message>
        <source>Firmware Revision String</source>
        <translation>固件修订字符串</translation>
    </message>
    <message>
        <source>Hardware Revision String</source>
        <translation>硬件修订字符串</translation>
    </message>
    <message>
        <source>Software Revision String</source>
        <translation>软件修订字符串</translation>
    </message>
    <message>
        <source>Manufacturer Name String</source>
        <translation>制造商名称字符串</translation>
    </message>
    <message>
        <source>IEEE 11073 20601 Regulatory Certification Data List</source>
        <translation>IEEE 11073 20601 法规认证数据列表</translation>
    </message>
    <message>
        <source>Current Time</source>
        <translation>当前时间</translation>
    </message>
    <message>
        <source>Scan Refresh</source>
        <translation>扫描刷新</translation>
    </message>
    <message>
        <source>Boot Keyboard Output Report</source>
        <translation>启动键盘输出报告</translation>
    </message>
    <message>
        <source>Boot Mouse Input Report</source>
        <translation>启动鼠标输入报告</translation>
    </message>
    <message>
        <source>Glucose Measurement Context</source>
        <translation>血糖测量范围</translation>
    </message>
    <message>
        <source>Blood Pressure Measurement</source>
        <translation>血压测量</translation>
    </message>
    <message>
        <source>Intermediate Cuff Pressure</source>
        <translation>中间袖带压力</translation>
    </message>
    <message>
        <source>Heart Rate Measurement</source>
        <translation>心率测量</translation>
    </message>
    <message>
        <source>Body Sensor Location</source>
        <translation>身体传感器位置</translation>
    </message>
    <message>
        <source>Heart Rate Control Point</source>
        <translation>心率控制点</translation>
    </message>
    <message>
        <source>Alert Status</source>
        <translation>警报状态</translation>
    </message>
    <message>
        <source>Ringer Control Point</source>
        <translation>振铃控制点</translation>
    </message>
    <message>
        <source>Ringer Setting</source>
        <translation>振铃设定</translation>
    </message>
    <message>
        <source>Alert Category ID Bit Mask</source>
        <translation>警报类别 ID 位掩码</translation>
    </message>
    <message>
        <source>Alert Category ID</source>
        <translation>警报类别 ID</translation>
    </message>
    <message>
        <source>Alert Notification Control Point</source>
        <translation>警报通知控制点</translation>
    </message>
    <message>
        <source>Unread Alert Status</source>
        <translation>未读警报状态</translation>
    </message>
    <message>
        <source>New Alert</source>
        <translation>新警报</translation>
    </message>
    <message>
        <source>Supported New Alert Category</source>
        <translation>支持的新警报类别</translation>
    </message>
    <message>
        <source>Supported Unread Alert Category</source>
        <translation>支持的未读警报类别</translation>
    </message>
    <message>
        <source>Blood Pressure Feature</source>
        <translation>血压功能</translation>
    </message>
    <message>
        <source>HID Information</source>
        <extracomment>HID: Human Interface Device Profile (Bluetooth)</extracomment>
        <translation>HID 信息</translation>
    </message>
    <message>
        <source>Report Map</source>
        <translation>报告图</translation>
    </message>
    <message>
        <source>HID Control Point</source>
        <extracomment>HID: Human Interface Device Profile (Bluetooth)</extracomment>
        <translation>HID 控制点</translation>
    </message>
    <message>
        <source>Report</source>
        <translation>报告</translation>
    </message>
    <message>
        <source>Protocol Mode</source>
        <translation>协议模式</translation>
    </message>
    <message>
        <source>Scan Interval Window</source>
        <translation>扫描间隔窗口</translation>
    </message>
    <message>
        <source>PnP ID</source>
        <translation>PnP ID</translation>
    </message>
    <message>
        <source>Glucose Feature</source>
        <translation>血糖功能</translation>
    </message>
    <message>
        <source>Record Access Control Point</source>
        <extracomment>Glucose Sensor patient record database.</extracomment>
        <translation>记录访问控制点</translation>
    </message>
    <message>
        <source>RSC Measurement</source>
        <extracomment>RSC: Running Speed and Cadence</extracomment>
        <translation>RSC 测量</translation>
    </message>
    <message>
        <source>RSC Feature</source>
        <extracomment>RSC: Running Speed and Cadence</extracomment>
        <translation>RSC 功能</translation>
    </message>
    <message>
        <source>SC Control Point</source>
        <translation>SC 控制点</translation>
    </message>
    <message>
        <source>CSC Measurement</source>
        <extracomment>CSC: Cycling Speed and Cadence</extracomment>
        <translation>CSC 测量</translation>
    </message>
    <message>
        <source>CSC Feature</source>
        <extracomment>CSC: Cycling Speed and Cadence</extracomment>
        <translation>CSC 功能</translation>
    </message>
    <message>
        <source>Sensor Location</source>
        <translation>传感器位置</translation>
    </message>
    <message>
        <source>Cycling Power Measurement</source>
        <translation>循环功率测量</translation>
    </message>
    <message>
        <source>Cycling Power Vector</source>
        <translation>循环功率矢量</translation>
    </message>
    <message>
        <source>Cycling Power Feature</source>
        <translation>循环功率功能</translation>
    </message>
    <message>
        <source>Cycling Power Control Point</source>
        <translation>循环功率控制点</translation>
    </message>
    <message>
        <source>Location And Speed</source>
        <translation>位置和速度</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>导航</translation>
    </message>
    <message>
        <source>Position Quality</source>
        <translation>位置质量</translation>
    </message>
    <message>
        <source>LN Feature</source>
        <translation>LN 功能</translation>
    </message>
    <message>
        <source>LN Control Point</source>
        <translation>LN 控制点</translation>
    </message>
    <message>
        <source>Magnetic Declination</source>
        <extracomment>Angle between geographic and magnetic north</extracomment>
        <translation>磁偏角</translation>
    </message>
    <message>
        <source>Elevation</source>
        <extracomment>Above/below sea level</extracomment>
        <translation>海拔</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>压力</translation>
    </message>
    <message>
        <source>Temperature</source>
        <translation>温度</translation>
    </message>
    <message>
        <source>Humidity</source>
        <translation>湿度</translation>
    </message>
    <message>
        <source>True Wind Speed</source>
        <extracomment>Wind speed while standing</extracomment>
        <translation>真实风速</translation>
    </message>
    <message>
        <source>True Wind Direction</source>
        <translation>真实风向</translation>
    </message>
    <message>
        <source>Apparent Wind Speed</source>
        <extracomment>Wind speed while observer is moving</extracomment>
        <translation>表观风速</translation>
    </message>
    <message>
        <source>Apparent Wind Direction</source>
        <translation>表观风向</translation>
    </message>
    <message>
        <source>Gust Factor</source>
        <extracomment>Factor by which wind gust is stronger than average wind</extracomment>
        <translation>阵风系数</translation>
    </message>
    <message>
        <source>Pollen Concentration</source>
        <translation>花粉浓度</translation>
    </message>
    <message>
        <source>UV Index</source>
        <translation>紫外线指数</translation>
    </message>
    <message>
        <source>Irradiance</source>
        <translation>辐照度</translation>
    </message>
    <message>
        <source>Rainfall</source>
        <translation>降雨量</translation>
    </message>
    <message>
        <source>Wind Chill</source>
        <translation>风寒</translation>
    </message>
    <message>
        <source>Heat Index</source>
        <translation>热指数</translation>
    </message>
    <message>
        <source>Dew Point</source>
        <translation>露点</translation>
    </message>
    <message>
        <source>Descriptor Value Changed</source>
        <extracomment>Environmental sensing related</extracomment>
        <translation>描述符值已更改</translation>
    </message>
    <message>
        <source>Aerobic Heart Rate Lower Limit</source>
        <translation>有氧心率下限</translation>
    </message>
    <message>
        <source>Aerobic Heart Rate Upper Limit</source>
        <translation>有氧心率上限</translation>
    </message>
    <message>
        <source>Aerobic Threshold</source>
        <translation>有氧阈值</translation>
    </message>
    <message>
        <source>Age</source>
        <extracomment>Age of person</extracomment>
        <translation>年龄</translation>
    </message>
    <message>
        <source>Anaerobic Heart Rate Lower Limit</source>
        <translation>无氧心率下限</translation>
    </message>
    <message>
        <source>Anaerobic Heart Rate Upper Limit</source>
        <translation>无氧心率上限</translation>
    </message>
    <message>
        <source>Anaerobic Threshold</source>
        <translation>无氧阈值</translation>
    </message>
    <message>
        <source>Date Of Birth</source>
        <translation>出生日期</translation>
    </message>
    <message>
        <source>Date Of Threshold Assessment</source>
        <translation>阈值评估日期</translation>
    </message>
    <message>
        <source>Email Address</source>
        <translation>电子邮件地址</translation>
    </message>
    <message>
        <source>Fat Burn Heart Rate Lower Limit</source>
        <translation>脂肪燃烧心率下限</translation>
    </message>
    <message>
        <source>Fat Burn Heart Rate Upper Limit</source>
        <translation>脂肪燃烧心率上限</translation>
    </message>
    <message>
        <source>First Name</source>
        <translation>名字</translation>
    </message>
    <message>
        <source>5-Zone Heart Rate Limits</source>
        <translation>5 区心率限制</translation>
    </message>
    <message>
        <source>Gender</source>
        <translation>性别</translation>
    </message>
    <message>
        <source>Heart Rate Maximum</source>
        <translation>心率最大值</translation>
    </message>
    <message>
        <source>Height</source>
        <extracomment>Height of a person</extracomment>
        <translation>高度</translation>
    </message>
    <message>
        <source>Hip Circumference</source>
        <translation>髋围</translation>
    </message>
    <message>
        <source>Last Name</source>
        <translation>姓</translation>
    </message>
    <message>
        <source>Maximum Recommended Heart Rate</source>
        <translation>最大推荐心率</translation>
    </message>
    <message>
        <source>Resting Heart Rate</source>
        <translation>静息心率</translation>
    </message>
    <message>
        <source>Sport Type For Aerobic/Anaerobic Thresholds</source>
        <translation>有氧/无氧阈值的运动类型</translation>
    </message>
    <message>
        <source>3-Zone Heart Rate Limits</source>
        <translation>3 区心率限制</translation>
    </message>
    <message>
        <source>2-Zone Heart Rate Limits</source>
        <translation>2 区心率限制</translation>
    </message>
    <message>
        <source>Oxygen Uptake</source>
        <translation>吸氧量</translation>
    </message>
    <message>
        <source>Waist Circumference</source>
        <translation>腰围</translation>
    </message>
    <message>
        <source>Weight</source>
        <translation>重量</translation>
    </message>
    <message>
        <source>Database Change Increment</source>
        <extracomment>Environmental sensing related</extracomment>
        <translation>数据库更改增量</translation>
    </message>
    <message>
        <source>User Index</source>
        <translation>用户索引</translation>
    </message>
    <message>
        <source>Body Composition Feature</source>
        <translation>身体成分功能</translation>
    </message>
    <message>
        <source>Body Composition Measurement</source>
        <translation>身体成分测量</translation>
    </message>
    <message>
        <source>Weight Measurement</source>
        <translation>重量测量</translation>
    </message>
    <message>
        <source>User Control Point</source>
        <translation>用户控制点</translation>
    </message>
    <message>
        <source>Magnetic Flux Density 2D</source>
        <translation>磁通密度 2D</translation>
    </message>
    <message>
        <source>Magnetic Flux Density 3D</source>
        <translation>磁通密度 3D</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>语言</translation>
    </message>
    <message>
        <source>Barometric Pressure Trend</source>
        <translation>气压趋势</translation>
    </message>
    <message>
        <source>Characteristic Extended Properties</source>
        <translation>特征扩展属性</translation>
    </message>
    <message>
        <source>Characteristic User Description</source>
        <translation>特征用户描述</translation>
    </message>
    <message>
        <source>Client Characteristic Configuration</source>
        <translation>客户端特征配置</translation>
    </message>
    <message>
        <source>Server Characteristic Configuration</source>
        <translation>服务器特性配置</translation>
    </message>
    <message>
        <source>Characteristic Presentation Format</source>
        <translation>特征表示格式</translation>
    </message>
    <message>
        <source>Characteristic Aggregate Format</source>
        <translation>特征聚合格式</translation>
    </message>
    <message>
        <source>Valid Range</source>
        <translation>有效范围</translation>
    </message>
    <message>
        <source>External Report Reference</source>
        <translation>外部报告参考</translation>
    </message>
    <message>
        <source>Report Reference</source>
        <translation>报告参考</translation>
    </message>
    <message>
        <source>Environmental Sensing Configuration</source>
        <translation>环境感应配置</translation>
    </message>
    <message>
        <source>Environmental Sensing Measurement</source>
        <translation>环境感应测量</translation>
    </message>
    <message>
        <source>Environmental Sensing Trigger Setting</source>
        <translation>环境感应触发设置</translation>
    </message>
    <message>
        <source>Unknown Service</source>
        <translation>未知服务</translation>
    </message>
</context>
<context>
    <name>QBluetoothSocket</name>
    <message>
        <source>Network Error</source>
        <translation>网络错误</translation>
    </message>
    <message>
        <source>Cannot write while not connected</source>
        <translation>未连接时无法写入</translation>
    </message>
    <message>
        <source>Trying to connect while connection is in progress</source>
        <translation>在连接正在进行时尝试连接</translation>
    </message>
    <message>
        <source>Service cannot be found</source>
        <translation>无法找到服务</translation>
    </message>
    <message>
        <source>Invalid data/data size</source>
        <translation>数据/数据大小 无效</translation>
    </message>
    <message>
        <source>Cannot read while not connected</source>
        <translation>未连接时无法读取</translation>
    </message>
    <message>
        <source>Cannot connect to %1</source>
        <comment>%1 = uuid</comment>
        <translation>无法连接到 %1</translation>
    </message>
    <message>
        <source>Device does not support Bluetooth</source>
        <translation>设备不支持蓝牙</translation>
    </message>
    <message>
        <source>Device is powered off</source>
        <translation>设备已关闭</translation>
    </message>
    <message>
        <source>Cannot access address %1</source>
        <comment>%1 = Bt address e.g. 11:22:33:44:55:66</comment>
        <translation>无法访问地址 %1</translation>
    </message>
    <message>
        <source>Cannot connect to %1 on %2</source>
        <comment>%1 = uuid, %2 = Bt address</comment>
        <translation>无法连接到 %2 上的 %1</translation>
    </message>
    <message>
        <source>Socket type not supported</source>
        <translation>套接字类型不受支持</translation>
    </message>
    <message>
        <source>Obtaining streams for service failed</source>
        <translation>获取服务流失败</translation>
    </message>
    <message>
        <source>Input stream thread cannot be started</source>
        <translation>输入流线程无法启动</translation>
    </message>
    <message>
        <source>Connection to service failed</source>
        <translation>连接服务失败</translation>
    </message>
    <message>
        <source>Error during write on socket.</source>
        <translation>写入套接字时出错。</translation>
    </message>
    <message>
        <source>Network error during read</source>
        <translation>读取期间网络错误</translation>
    </message>
    <message>
        <source>Unknown socket error</source>
        <translation>未知的套接字错误</translation>
    </message>
    <message>
        <source>Cannot set connection security level</source>
        <translation>无法设置连接安全级别</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>网络错误：%1</translation>
    </message>
    <message>
        <source>Cannot export profile on DBus</source>
        <translation>无法导出 DBUS 上的配置文件</translation>
    </message>
    <message>
        <source>Cannot register profile on DBus</source>
        <translation>无法在 DBUS 上注册配置文件</translation>
    </message>
    <message>
        <source>Cannot find remote device</source>
        <translation>找不到远程设备</translation>
    </message>
    <message>
        <source>Cannot connect to remote profile</source>
        <translation>无法连接到远程配置文件</translation>
    </message>
    <message>
        <source>Missing serviceUuid or Serial Port service class uuid</source>
        <translation>缺少服务 Uuid 或串口服务类 uuid</translation>
    </message>
    <message>
        <source>Invalid Bluetooth address passed to connectToService()</source>
        <translation>传递给 ConnectToService() 的蓝牙地址无效</translation>
    </message>
    <message>
        <source>Network error</source>
        <translation>网络错误</translation>
    </message>
    <message>
        <source>Remote host closed connection</source>
        <translation>远程主机关闭连接</translation>
    </message>
    <message>
        <source>Connection timed out</source>
        <translation>连接超时</translation>
    </message>
    <message>
        <source>Host not reachable</source>
        <translation>主机无法访问</translation>
    </message>
    <message>
        <source>Host refused connection</source>
        <translation>主机拒绝连接</translation>
    </message>
</context>
<context>
    <name>QBluetoothSocketPrivateAndroid</name>
    <message>
        <source>Connecting to port is not supported</source>
        <translation>不支持连接到端口</translation>
    </message>
</context>
<context>
    <name>QBluetoothSocketPrivateBluezDBus</name>
    <message>
        <source>Connecting to port is not supported via Bluez DBus</source>
        <translation>Bluez DBus 不支持连接到端口</translation>
    </message>
</context>
<context>
    <name>QBluetoothTransferReply</name>
    <message>
        <source>Invalid target address</source>
        <translation>目标地址无效</translation>
    </message>
    <message>
        <source>Push session cannot be started</source>
        <translation>无法启动推送会话</translation>
    </message>
    <message>
        <source>Push session cannot connect</source>
        <translation>推送会话无法连接</translation>
    </message>
    <message>
        <source>Source file does not exist</source>
        <translation>源文件不存在</translation>
    </message>
    <message>
        <source>QIODevice cannot be read. Make sure it is open for reading.</source>
        <translation>QIODevice 无法读取。确保它是开放读取的。</translation>
    </message>
    <message>
        <source>Push session failed</source>
        <translation>推送会话失败</translation>
    </message>
    <message>
        <source>Invalid input device (null)</source>
        <translation>输入设备无效（null）</translation>
    </message>
    <message>
        <source>Operation canceled</source>
        <translation>操作被取消</translation>
    </message>
    <message>
        <source>Transfer already started</source>
        <translation>传输已开始</translation>
    </message>
    <message>
        <source>Push service not found</source>
        <translation>未找到推送服务</translation>
    </message>
</context>
<context>
    <name>QBluetoothTransferReplyBluez</name>
    <message>
        <source>Unknown Error</source>
        <translation>未知错误</translation>
    </message>
    <message>
        <source>Could not open file for sending</source>
        <translation>无法打开文件进行发送</translation>
    </message>
    <message>
        <source>The transfer was canceled</source>
        <translation>传输被取消了</translation>
    </message>
    <message>
        <source>Operation canceled</source>
        <translation>操作被取消</translation>
    </message>
</context>
<context>
    <name>QLowEnergyController</name>
    <message>
        <source>Remote device cannot be found</source>
        <translation>找不到远程设备</translation>
    </message>
    <message>
        <source>Cannot find local adapter</source>
        <translation>找不到本地适配器</translation>
    </message>
    <message>
        <source>Error occurred during connection I/O</source>
        <translation>连接 I/O 期间出错</translation>
    </message>
    <message>
        <source>Unknown Error</source>
        <translation>未知错误</translation>
    </message>
    <message>
        <source>Advertisement data is larger than 31 bytes</source>
        <translation>广告数据大于 31 字节</translation>
    </message>
    <message>
        <source>Advertisement feature not supported on the platform</source>
        <translation>平台不支持广告功能</translation>
    </message>
    <message>
        <source>Error occurred trying to start advertising</source>
        <translation>尝试启动广告时出错</translation>
    </message>
    <message>
        <source>Failed due to too many advertisers</source>
        <translation>由于广告商太多而失败</translation>
    </message>
    <message>
        <source>Unknown advertisement error</source>
        <translation>未知的广告错误</translation>
    </message>
    <message>
        <source>Error occurred trying to connect to remote device.</source>
        <translation>尝试连接到远程设备时出错。</translation>
    </message>
    <message>
        <source>Remote device closed the connection</source>
        <translation>远程设备已关闭连接</translation>
    </message>
</context>
</TS>
